@@ -6,21 +6,19 @@
     Test the autodoc extension.  This tests mainly the Documenters; the auto
     directives are tested in a test source file translated by test_build.
 
-    :copyright: Copyright 2007-2013 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-import sys
-from StringIO import StringIO
-
 # "raises" imported for usage by autodoc
 from util import TestApp, Struct, raises
 from nose.tools import with_setup
 
+from six import StringIO
 from docutils.statemachine import ViewList
 
 from sphinx.ext.autodoc import AutoDirective, add_documenter, \
-     ModuleLevelDocumenter, FunctionDocumenter, cut_lines, between, ALL
+    ModuleLevelDocumenter, FunctionDocumenter, cut_lines, between, ALL
 
 app = None
 
@@ -125,24 +123,24 @@ def test_parse_name():
     directive.env.temp_data['autodoc:module'] = 'util'
     verify('function', 'raises', ('util', ['raises'], None, None))
     del directive.env.temp_data['autodoc:module']
-    directive.env.temp_data['py:module'] = 'util'
+    directive.env.ref_context['py:module'] = 'util'
     verify('function', 'raises', ('util', ['raises'], None, None))
     verify('class', 'TestApp', ('util', ['TestApp'], None, None))
 
     # for members
-    directive.env.temp_data['py:module'] = 'foo'
+    directive.env.ref_context['py:module'] = 'foo'
     verify('method', 'util.TestApp.cleanup',
            ('util', ['TestApp', 'cleanup'], None, None))
-    directive.env.temp_data['py:module'] = 'util'
-    directive.env.temp_data['py:class'] = 'Foo'
+    directive.env.ref_context['py:module'] = 'util'
+    directive.env.ref_context['py:class'] = 'Foo'
     directive.env.temp_data['autodoc:class'] = 'TestApp'
     verify('method', 'cleanup', ('util', ['TestApp', 'cleanup'], None, None))
     verify('method', 'TestApp.cleanup',
            ('util', ['TestApp', 'cleanup'], None, None))
 
     # and clean up
-    del directive.env.temp_data['py:module']
-    del directive.env.temp_data['py:class']
+    del directive.env.ref_context['py:module']
+    del directive.env.ref_context['py:class']
     del directive.env.temp_data['autodoc:class']
 
 
@@ -153,9 +151,12 @@ def test_format_signature():
         inst.fullname = name
         inst.doc_as_attr = False  # for class objtype
         inst.object = obj
+        inst.objpath = [name]
         inst.args = args
         inst.retann = retann
-        return inst.format_signature()
+        res = inst.format_signature()
+        print(res)
+        return res
 
     # no signatures for modules
     assert formatsig('module', 'test', None, None, None) == ''
@@ -163,10 +164,13 @@ def test_format_signature():
     # test for functions
     def f(a, b, c=1, **d):
         pass
+    def g(a='\n'):
+        pass
     assert formatsig('function', 'f', f, None, None) == '(a, b, c=1, **d)'
     assert formatsig('function', 'f', f, 'a, b, c, d', None) == '(a, b, c, d)'
     assert formatsig('function', 'f', f, None, 'None') == \
            '(a, b, c=1, **d) -> None'
+    assert formatsig('function', 'g', g, None, None) == r"(a='\\n')"
 
     # test for classes
     class D:
@@ -185,7 +189,8 @@ def test_format_signature():
         assert formatsig('class', 'C', C, None, None) == '(a, b=None)'
     assert formatsig('class', 'C', D, 'a, b', 'X') == '(a, b) -> X'
 
-    #__init__ have signature at first line of docstring
+    # __init__ have signature at first line of docstring
+    directive.env.config.autoclass_content = 'both'
     class F2:
         '''some docstring for F2.'''
         def __init__(self, *args, **kw):
@@ -196,9 +201,11 @@ def test_format_signature():
             '''
     class G2(F2, object):
         pass
-    for C in (F2, G2):
-        assert formatsig('class', 'C', C, None, None) == \
-            '(a1, a2, kw1=True, kw2=False)'
+
+    assert formatsig('class', 'F2', F2, None, None) == \
+        '(a1, a2, kw1=True, kw2=False)'
+    assert formatsig('class', 'G2', G2, None, None) == \
+        '(a1, a2, kw1=True, kw2=False)'
 
     # test for methods
     class H:
@@ -206,11 +213,15 @@ def test_format_signature():
             pass
         def foo2(b, *c):
             pass
+        def foo3(self, d='\n'):
+            pass
     assert formatsig('method', 'H.foo', H.foo1, None, None) == '(b, *c)'
     assert formatsig('method', 'H.foo', H.foo1, 'a', None) == '(a)'
     assert formatsig('method', 'H.foo', H.foo2, None, None) == '(b, *c)'
+    assert formatsig('method', 'H.foo', H.foo3, None, None) == r"(d='\\n')"
 
     # test exception handling (exception is caught and args is '')
+    directive.env.config.autodoc_docstring_signature = False
     assert formatsig('function', 'int', int, None, None) == ''
     del _warnings[:]
 
@@ -238,9 +249,14 @@ def test_get_doc():
     def getdocl(objtype, obj, encoding=None):
         inst = AutoDirective._registry[objtype](directive, 'tmp')
         inst.object = obj
+        inst.objpath = [obj.__name__]
+        inst.doc_as_attr = False
+        inst.format_signature()  # handle docstring signatures!
         ds = inst.get_doc(encoding)
         # for testing purposes, concat them and strip the empty line at the end
-        return sum(ds, [])[:-1]
+        res = sum(ds, [])[:-1]
+        print(res)
+        return res
 
     # objects without docstring
     def f():
@@ -301,7 +317,7 @@ def test_get_doc():
     assert getdocl('class', D) == ['Class docstring', '', 'Init docstring',
                                    '', 'Other', ' lines']
 
-    #__init__ have signature at first line of docstring
+    # __init__ have signature at first line of docstring
     class E:
         """Class docstring"""
         def __init__(self, *args, **kw):
@@ -326,7 +342,7 @@ def test_get_doc():
 
     # signature line in the docstring will be removed when
     # autodoc_docstring_signature == True
-    directive.env.config.autodoc_docstring_signature = True  #default
+    directive.env.config.autodoc_docstring_signature = True  # default
     directive.env.config.autoclass_content = 'class'
     assert getdocl('class', E) == ['Class docstring']
     directive.env.config.autoclass_content = 'init'
@@ -348,6 +364,22 @@ def test_get_doc():
         directive.env.config.autoclass_content = 'both'
         assert getdocl('class', F) == ['Class docstring']
 
+    # class has __init__ method with no docstring
+    class G(object):
+        """Class docstring"""
+        def __init__(self):
+            pass
+
+    # docstring in the __init__ method of base class will not be used
+    for f in (False, True):
+        directive.env.config.autodoc_docstring_signature = f
+        directive.env.config.autoclass_content = 'class'
+        assert getdocl('class', G) == ['Class docstring']
+        directive.env.config.autoclass_content = 'init'
+        assert getdocl('class', G) == ['Class docstring']
+        directive.env.config.autoclass_content = 'both'
+        assert getdocl('class', G) == ['Class docstring']
+
 
 @with_setup(setup_test)
 def test_docstring_processing():
@@ -401,6 +433,43 @@ def test_docstring_processing():
     app.disconnect(lid)
 
 
+@with_setup(setup_test)
+def test_docstring_property_processing():
+    def genarate_docstring(objtype, name, **kw):
+        del processed_docstrings[:]
+        del processed_signatures[:]
+        inst = AutoDirective._registry[objtype](directive, name)
+        inst.generate(**kw)
+        results = list(directive.result)
+        docstrings = inst.get_doc()[0]
+        del directive.result[:]
+        return results, docstrings
+
+    directive.env.config.autodoc_docstring_signature = False
+    results, docstrings = \
+        genarate_docstring('attribute', 'test_autodoc.DocstringSig.prop1')
+    assert '.. py:attribute:: DocstringSig.prop1' in results
+    assert 'First line of docstring' in docstrings
+    assert 'DocstringSig.prop1(self)' in docstrings
+    results, docstrings = \
+        genarate_docstring('attribute', 'test_autodoc.DocstringSig.prop2')
+    assert '.. py:attribute:: DocstringSig.prop2' in results
+    assert 'First line of docstring' in docstrings
+    assert 'Second line of docstring' in docstrings
+
+    directive.env.config.autodoc_docstring_signature = True
+    results, docstrings = \
+        genarate_docstring('attribute', 'test_autodoc.DocstringSig.prop1')
+    assert '.. py:attribute:: DocstringSig.prop1' in results
+    assert 'First line of docstring' in docstrings
+    assert 'DocstringSig.prop1(self)' not in docstrings
+    results, docstrings = \
+        genarate_docstring('attribute', 'test_autodoc.DocstringSig.prop2')
+    assert '.. py:attribute:: DocstringSig.prop2' in results
+    assert 'First line of docstring' in docstrings
+    assert 'Second line of docstring' in docstrings
+
+
 @with_setup(setup_test)
 def test_new_documenter():
     class MyDocumenter(ModuleLevelDocumenter):
@@ -526,9 +595,12 @@ def test_generate():
     # attributes missing
     assert_warns("failed to import function 'foobar' from module 'util'",
                  'function', 'util.foobar', more_content=None)
+    # method missing
+    assert_warns("failed to import method 'Class.foobar' from module 'test_autodoc';",
+                 'method', 'test_autodoc.Class.foobar', more_content=None)
 
     # test auto and given content mixing
-    directive.env.temp_data['py:module'] = 'test_autodoc'
+    directive.env.ref_context['py:module'] = 'test_autodoc'
     assert_result_contains('   Function.', 'method', 'Class.meth')
     add_content = ViewList()
     add_content.append('Content.', '', 0)
@@ -626,12 +698,12 @@ def test_generate():
                            'attribute', 'test_autodoc.Class.descr')
 
     # test generation for C modules (which have no source file)
-    directive.env.temp_data['py:module'] = 'time'
+    directive.env.ref_context['py:module'] = 'time'
     assert_processes([('function', 'time.asctime')], 'function', 'asctime')
     assert_processes([('function', 'time.asctime')], 'function', 'asctime')
 
     # test autodoc_member_order == 'source'
-    directive.env.temp_data['py:module'] = 'test_autodoc'
+    directive.env.ref_context['py:module'] = 'test_autodoc'
     assert_order(['.. py:class:: Class(arg)',
                   '   .. py:attribute:: Class.descr',
                   '   .. py:method:: Class.meth()',
@@ -648,7 +720,7 @@ def test_generate():
                   '   .. py:method:: Class.inheritedmeth()',
                   ],
                  'class', 'Class', member_order='bysource', all_members=True)
-    del directive.env.temp_data['py:module']
+    del directive.env.ref_context['py:module']
 
     # test attribute initialized to class instance from other module
     directive.env.temp_data['autodoc:class'] = 'test_autodoc.Class'
@@ -673,7 +745,7 @@ def test_generate():
         'test_autodoc.Class.moore')
 
     # test new attribute documenter behavior
-    directive.env.temp_data['py:module'] = 'test_autodoc'
+    directive.env.ref_context['py:module'] = 'test_autodoc'
     options.undoc_members = True
     assert_processes([('class', 'test_autodoc.AttCls'),
                       ('attribute', 'test_autodoc.AttCls.a1'),
@@ -687,7 +759,7 @@ def test_generate():
     # test explicit members with instance attributes
     del directive.env.temp_data['autodoc:class']
     del directive.env.temp_data['autodoc:module']
-    directive.env.temp_data['py:module'] = 'test_autodoc'
+    directive.env.ref_context['py:module'] = 'test_autodoc'
     options.inherited_members = False
     options.undoc_members = False
     options.members = ALL
@@ -709,7 +781,7 @@ def test_generate():
     ], 'class', 'InstAttCls')
     del directive.env.temp_data['autodoc:class']
     del directive.env.temp_data['autodoc:module']
-    del directive.env.temp_data['py:module']
+    del directive.env.ref_context['py:module']
 
     # test descriptor class documentation
     options.members = ['CustomDataDescriptor']
@@ -751,12 +823,8 @@ def _funky_classmethod(name, b, c, d, docstring=None):
     some arguments."""
     def template(cls, a, b, c, d=4, e=5, f=6):
         return a, b, c, d, e, f
-    if sys.version_info >= (2, 5):
-        from functools import partial
-        function = partial(template, b=b, c=c, d=d)
-    else:
-        def function(cls, a, e=5, f=6):
-            return template(a, b, c, d, e, f)
+    from functools import partial
+    function = partial(template, b=b, c=c, d=d)
     function.__name__ = name
     function.__doc__ = docstring
     return classmethod(function)
@@ -788,10 +856,9 @@ class Class(Base):
     #: should be documented -- süß
     attr = 'bar'
 
+    @property
     def prop(self):
         """Property."""
-    # stay 2.4 compatible (docstring!)
-    prop = property(prop, doc="Property.")
 
     docattr = 'baz'
     """should likewise be documented -- süß"""
@@ -861,6 +928,20 @@ First line of docstring
             indented line
         """
 
+    @property
+    def prop1(self):
+        """DocstringSig.prop1(self)
+        First line of docstring
+        """
+        return 123
+
+    @property
+    def prop2(self):
+        """First line of docstring
+        Second line of docstring
+        """
+        return 456
+
 class StrRepr(str):
     def __repr__(self):
         return self
