@@ -7,13 +7,14 @@
     Make sure each Python file has a correct file header
     including copyright and license information.
 
-    :copyright: 2006-2007 by Georg Brandl.
-    :license: GNU GPL, see LICENSE for more details.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
+from __future__ import print_function
 
 import sys, os, re
-import getopt
 import cStringIO
+from optparse import OptionParser
 from os.path import join, splitext, abspath
 
 
@@ -30,47 +31,50 @@ def checker(*suffixes, **kwds):
 
 
 name_mail_re = r'[\w ]+(<.*?>)?'
-copyright_re = re.compile(r'^    :copyright: 200\d(-200\d)? by %s(, %s)*[,.]$' %
+copyright_re = re.compile(br'^    :copyright: Copyright 200\d(-20\d\d)? '
+                          br'by %s(, %s)*[,.]$' %
                           (name_mail_re, name_mail_re))
-license_re = re.compile(r"    :license: (.*?).\n")
-copyright_2_re = re.compile(r'^                %s(, %s)*[,.]$' %
+license_re = re.compile(br"    :license: (.*?).\n")
+copyright_2_re = re.compile(br'^                %s(, %s)*[,.]$' %
                             (name_mail_re, name_mail_re))
-coding_re    = re.compile(r'coding[:=]\s*([-\w.]+)')
-not_ix_re    = re.compile(r'\bnot\s+\S+?\s+i[sn]\s\S+')
-is_const_re  = re.compile(r'if.*?==\s+(None|False|True)\b')
+coding_re    = re.compile(br'coding[:=]\s*([-\w.]+)')
+not_ix_re    = re.compile(br'\bnot\s+\S+?\s+i[sn]\s\S+')
+is_const_re  = re.compile(br'if.*?==\s+(None|False|True)\b')
 
-misspellings = ["developement", "adress", "verificate",  # ALLOW-MISSPELLING
-                "informations"]                          # ALLOW-MISSPELLING
+misspellings = [b"developement", b"adress", # ALLOW-MISSPELLING
+                b"verificate", b"informations"] # ALLOW-MISSPELLING
 
-
-@checker('.py')
-def check_syntax(fn, lines):
-    try:
-        compile(''.join(lines), fn, "exec")
-    except SyntaxError, err:
-        yield 0, "not compilable: %s" % err
+if sys.version_info < (3, 0):
+    @checker('.py')
+    def check_syntax(fn, lines):
+        try:
+            compile(b''.join(lines), fn, "exec")
+        except SyntaxError as err:
+            yield 0, "not compilable: %s" % err
 
 
 @checker('.py')
 def check_style_and_encoding(fn, lines):
     encoding = 'ascii'
     for lno, line in enumerate(lines):
-        if len(line) > 90:
+        if len(line) > 95:
             yield lno+1, "line too long"
-        m = not_ix_re.search(line)
-        if m:
-            yield lno+1, '"' + m.group() + '"'
-        if is_const_re.search(line):
-            yield lno+1, 'using == None/True/False'
         if lno < 2:
             co = coding_re.search(line)
             if co:
-                encoding = co.group(1)
+                encoding = co.group(1).decode('ascii')
+        if line.strip().startswith(b'#'):
+            continue
+        #m = not_ix_re.search(line)
+        #if m:
+        #    yield lno+1, '"' + m.group() + '"'
+        if is_const_re.search(line):
+            yield lno+1, 'using == None/True/False'
         try:
             line.decode(encoding)
-        except UnicodeDecodeError, err:
+        except UnicodeDecodeError as err:
             yield lno+1, "not decodable: %s\n   Line: %r" % (err, line)
-        except LookupError, err:
+        except LookupError as err:
             yield 0, "unknown encoding: %s" % encoding
             encoding = 'latin1'
 
@@ -79,7 +83,7 @@ def check_style_and_encoding(fn, lines):
 def check_fileheader(fn, lines):
     # line number correction
     c = 1
-    if lines[0:1] == ['#!/usr/bin/env python\n']:
+    if lines[0:1] == [b'#!/usr/bin/env python\n']:
         lines = lines[1:]
         c = 2
 
@@ -88,38 +92,38 @@ def check_fileheader(fn, lines):
     for lno, l in enumerate(lines):
         llist.append(l)
         if lno == 0:
-            if l == '# -*- coding: rot13 -*-\n':
+            if l == b'# -*- coding: rot13 -*-\n':
                 # special-case pony package
                 return
-            elif l != '# -*- coding: utf-8 -*-\n':
+            elif l != b'# -*- coding: utf-8 -*-\n':
                 yield 1, "missing coding declaration"
         elif lno == 1:
-            if l != '"""\n' and l != 'r"""\n':
+            if l != b'"""\n' and l != b'r"""\n':
                 yield 2, 'missing docstring begin (""")'
             else:
                 docopen = True
         elif docopen:
-            if l == '"""\n':
+            if l == b'"""\n':
                 # end of docstring
                 if lno <= 4:
                     yield lno+c, "missing module name in docstring"
                 break
 
-            if l != "\n" and l[:4] != '    ' and docopen:
+            if l != b"\n" and l[:4] != b'    ' and docopen:
                 yield lno+c, "missing correct docstring indentation"
 
             if lno == 2:
                 # if not in package, don't check the module name
                 modname = fn[:-3].replace('/', '.').replace('.__init__', '')
                 while modname:
-                    if l.lower()[4:-1] == modname:
+                    if l.lower()[4:-1] == bytes(modname):
                         break
                     modname = '.'.join(modname.split('.')[1:])
                 else:
                     yield 3, "wrong module name in docstring heading"
                 modnamelen = len(l.strip())
             elif lno == 3:
-                if l.strip() != modnamelen * "~":
+                if l.strip() != modnamelen * b"~":
                     yield 4, "wrong module name underline, should be ~~~...~"
 
     else:
@@ -139,20 +143,19 @@ def check_fileheader(fn, lines):
         yield 0, "no correct copyright info"
 
 
-@checker('.py', '.html')
+@checker('.py', '.html', '.rst')
 def check_whitespace_and_spelling(fn, lines):
     for lno, line in enumerate(lines):
-        if "\t" in line:
+        if b"\t" in line:
             yield lno+1, "OMG TABS!!!1 "
-        if line[:-1].rstrip(' \t') != line[:-1]:
+        if line[:-1].rstrip(b' \t') != line[:-1]:
             yield lno+1, "trailing whitespace"
         for word in misspellings:
-            if word in line and 'ALLOW-MISSPELLING' not in line:
+            if word in line and b'ALLOW-MISSPELLING' not in line:
                 yield lno+1, '"%s" used' % word
 
 
-bad_tags = ('<b>', '<i>', '<u>', '<s>', '<strike>'
-            '<center>', '<big>', '<small>', '<font')
+bad_tags = [b'<u>', b'<s>', b'<strike>', b'<center>', b'<font']
 
 @checker('.html')
 def check_xhtml(fn, lines):
@@ -163,37 +166,32 @@ def check_xhtml(fn, lines):
 
 
 def main(argv):
-    try:
-        gopts, args = getopt.getopt(argv[1:], "vi:")
-    except getopt.GetoptError:
-        print "Usage: %s [-v] [-i ignorepath]* [path]" % argv[0]
-        return 2
-    opts = {}
-    for opt, val in gopts:
-        if opt == '-i':
-            val = abspath(val)
-        opts.setdefault(opt, []).append(val)
+    parser = OptionParser(usage='Usage: %prog [-v] [-i ignorepath]* [path]')
+    parser.add_option('-v', '--verbose', dest='verbose', default=False,
+                      action='store_true')
+    parser.add_option('-i', '--ignore-path', dest='ignored_paths',
+                      default=[], action='append')
+    options, args = parser.parse_args(argv[1:])
 
     if len(args) == 0:
         path = '.'
     elif len(args) == 1:
         path = args[0]
     else:
-        print "Usage: %s [-v] [-i ignorepath]* [path]" % argv[0]
-        return 2
+        print(args)
+        parser.error('No more then one path supported')
 
-    verbose = '-v' in opts
+    verbose = options.verbose
+    ignored_paths = set(abspath(p) for p in options.ignored_paths)
 
     num = 0
     out = cStringIO.StringIO()
 
-    # TODO: replace os.walk run with iteration over output of
-    #       `svn list -R`.
-
     for root, dirs, files in os.walk(path):
-        if '.svn' in dirs:
-            dirs.remove('.svn')
-        if '-i' in opts and abspath(root) in opts['-i']:
+        for vcs_dir in ['.svn', '.hg', '.git']:
+            if vcs_dir in dirs:
+                dirs.remove(vcs_dir)
+        if abspath(root) in ignored_paths:
             del dirs[:]
             continue
         in_check_pkg = root.startswith('./sphinx')
@@ -202,7 +200,7 @@ def main(argv):
             fn = join(root, fn)
             if fn[:2] == './': fn = fn[2:]
 
-            if '-i' in opts and abspath(fn) in opts['-i']:
+            if abspath(fn) in ignored_paths:
                 continue
 
             ext = splitext(fn)[1]
@@ -211,13 +209,16 @@ def main(argv):
                 continue
 
             if verbose:
-                print "Checking %s..." % fn
+                print("Checking %s..." % fn)
 
             try:
-                f = open(fn, 'r')
-                lines = list(f)
-            except (IOError, OSError), err:
-                print "%s: cannot open: %s" % (fn, err)
+                f = open(fn, 'rb')
+                try:
+                    lines = list(f)
+                finally:
+                    f.close()
+            except (IOError, OSError) as err:
+                print("%s: cannot open: %s" % (fn, err))
                 num += 1
                 continue
 
@@ -225,15 +226,15 @@ def main(argv):
                 if not in_check_pkg and checker.only_pkg:
                     continue
                 for lno, msg in checker(fn, lines):
-                    print >>out, "%s:%d: %s" % (fn, lno, msg)
+                    print("%s:%d: %s" % (fn, lno, msg), file=out)
                     num += 1
     if verbose:
-        print
+        print()
     if num == 0:
-        print "No errors found."
+        print("No errors found.")
     else:
-        print out.getvalue().rstrip('\n')
-        print "%d error%s found." % (num, num > 1 and "s" or "")
+        print(out.getvalue().rstrip('\n'))
+        print("%d error%s found." % (num, num > 1 and "s" or ""))
     return int(num > 0)
 
 
